isEqualNode method
Tests whether this node is equal to other.
The two nodes are equal when they have the same type, name, defining characteristics, attributes, and children.
Implementation
bool isEqualNode(XmlNode other) =>
this == other ||
(runtimeType == other.runtimeType &&
_compareName(this, other) &&
_compareData(this, other) &&
_compareList(attributes, other.attributes) &&
_compareList(children, other.children));