getAttribute method

String? getAttribute(
  1. String name, {
  2. String? namespaceUri,
  3. @Deprecated('Use `namespaceUri` instead') String? namespace,
})
inherited

Return the attribute value with the given name, or null.

Both name and namespaceUri can be a specific String; or '*' to match anything. If no namespaceUri is provided, the fully qualified name is compared; otherwise only the local name is considered.

For example:

  • element.getAttribute('xsd:name') returns the first attribute value with the fully qualified attribute name xsd:name.
  • element.getAttribute('name', namespaceUri: '*') returns the first attribute value with the local attribute name name no matter the namespace.
  • element.getAttribute('*', namespaceUri: 'http://www.w3.org/2001/XMLSchema') returns the first attribute value within the provided namespace URI.

Implementation

String? getAttribute(
  String name, {
  String? namespaceUri,
  @Deprecated('Use `namespaceUri` instead') String? namespace,
}) => null;