setAttribute method
void
setAttribute(
- String name,
- String? value, {
- String? namespaceUri,
- @Deprecated('Use `namespaceUri` instead') String? namespace,
inherited
Set the attribute value with the given fully qualified name to value.
If an attribute with the name already exist, its value is updated.
If the value is null, the attribute is removed.
Both name and namespaceUri can be a specific String; or '*' to match
anything. If no namespaceUri is provided, the fully qualified name is
compared; otherwise only the local name is considered.
For example:
element.setAttribute('xsd:name', 'value')updates the attribute with the fully qualified attribute namexsd:name.element.setAttribute('name', 'value', namespaceUri: '*')updates the attribute with the local attribute namenameno matter the namespace.element.setAttribute('*', 'value', namespaceUri: 'http://www.w3.org/2001/XMLSchema')updates the attribute within the provided namespace URI.
Implementation
void setAttribute(
String name,
String? value, {
String? namespaceUri,
@Deprecated('Use `namespaceUri` instead') String? namespace,
}) => throw UnsupportedError('$this has no attributes');