innerXml property
String
get
innerXml
Return the markup representing the child nodes of this node.
Implementation
String get innerXml => children.map((node) => node.toXmlString()).join();
set
innerXml
(String value)
Replaces the markup representing the child nodes of this node.
Implementation
set innerXml(String value) {
XmlNodeTypeException.checkHasChildren(this);
children.clear();
if (value.isNotEmpty) {
children.add(XmlDocumentFragment.parse(value));
}
}