outerXml property

String get outerXml

Return the markup representing this node and all its child nodes.

Implementation

String get outerXml => toXmlString();
set outerXml (String value)

Replaces the markup representing this node and all its child nodes.

Implementation

set outerXml(String value) => replace(XmlDocumentFragment.parse(value));