XmlEventDecoder class

A converter that decodes a String to a sequence of XmlEvent objects.

Inheritance

Constructors

XmlEventDecoder({XmlEntityMapping? entityMapping, bool validateDocument = false, bool validateNamespace = false, bool validateNesting = false, bool withLocation = false, bool withNamespace = false, bool withParent = false})
Creates a new XmlEventDecoder.

Properties

entityMapping → XmlEntityMapping
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateDocument → bool
final
validateNamespace → bool
final
validateNesting → bool
final
withLocation → bool
final
withNamespace → bool
final
withParent → bool
final

Methods

bind(Stream<String> stream) → Stream<List<XmlEvent>>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(String input, [int start = 0, int? end]) → List<XmlEvent>
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<List<XmlEvent>, TT> other) → Converter<String, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<List<XmlEvent>> sink) → StringConversionSink
Starts a chunked conversion.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited