XmlEventEncoder class

A converter that encodes a sequence of XmlEvent objects to a String.

Inheritance

Constructors

XmlEventEncoder({XmlEntityMapping? entityMapping})
Creates a converter that encodes XML events to a string.

Properties

entityMapping → XmlEntityMapping
The entity mapping used to encode text and attribute values.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<List<XmlEvent>> stream) → Stream<String>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(List<XmlEvent> input) → String
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<String, TT> other) → Converter<List<XmlEvent>, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<String> sink) → ChunkedConversionSink<List<XmlEvent>>
Starts a chunked conversion.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited