XmlProcessingEvent class

Event of an XML processing node.

Inheritance

Constructors

XmlProcessingEvent(String target, String value)
Creates a processing event with target and value.

Properties

buffer → String?
The underlying buffer.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
nodeType → XmlNodeType
The node type of this node.
no setteroverride
parent → XmlStartElementEvent?
The parent event of type XmlStartElementEvent, or null.
no setterinherited
parentEvent → XmlStartElementEvent?
The parent event of type XmlStartElementEvent, or null.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int?
The start location in the input buffer, or null.
no setterinherited
stop → int?
The stop location in the input buffer, or null.
no setterinherited
target → String
The processing target.
final
text → String
no setter
value → String
The processing value.
final

Methods

accept(XmlEventVisitor visitor) → void
Dispatches to the visitor based on event type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override