XmlStartElementEvent class

Event of an XML start element node.

Inheritance

Constructors

XmlStartElementEvent(String name, List<XmlEventAttribute> attributes, bool isSelfClosing)
Creates a start element event with name, attributes, and isSelfClosing.

Properties

attributes → List<XmlEventAttribute>
The attributes of this start element.
final
buffer → String?
The underlying buffer.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
isSelfClosing → bool
Whether the start element is self-closing.
final
localName → String
The local name, excluding the namespace prefix.
no setterinherited
name → String
The fully qualified name.
final
namespacePrefix → String?
The namespace prefix, or null.
no setterinherited
namespaceUri → String?
The namespace URI, or null.
no setterinherited
nodeType → XmlNodeType
The node type of this node.
no setteroverride
parent → XmlStartElementEvent?
The parent event of type XmlStartElementEvent, or null.
no setterinherited
parentEvent → XmlStartElementEvent?
The parent event of type XmlStartElementEvent, or null.
no setterinherited
qualifiedName → String
The fully qualified name (alias for name).
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int?
The start location in the input buffer, or null.
no setterinherited
stop → int?
The stop location in the input buffer, or null.
no setterinherited

Methods

accept(XmlEventVisitor visitor) → void
Dispatches to the visitor based on event type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override