XPathArray class final

Represents an XDM 3.1 array item (array(*)).

Inheritance

Constructors

XPathArray([List<XPathSequence> members = const []])
Creates an array item with members.
const

Properties

arity → int
The arity (number of required arguments) of the function item.
no setteroverride
effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
isEmpty → bool
Whether this array contains no members.
no setter
isNotEmpty → bool
Whether this array contains at least one member.
no setter
isVariadic → bool
Whether this function accepts variable arguments (at least arity).
no setterinherited
length → int
The number of members in the array.
no setter
members → List<XPathSequence>
The ordered members of the array (each member is an XPathSequence).
final
name → XmlName
The name of the function, if named.
no setterinherited
parameterTypes → List<XPathType>?
The parameter types of the function, if statically known.
no setterinherited
returnType → XPathType?
The return type of the function, if statically known.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String
Canonical string representation of this item.
no setterinherited
type → XPathType
The XDM type of this item.
no setteroverride

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
inherited
call(XPathContext context, List<XPathSequence> arguments) → XPathSequence
Invokes the function item with the given arguments.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toValue() → List<Object?>
Converts this item to a native Dart value.
override

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](int index) → XPathSequence
Returns the member at the 0-based index.

Constants

empty → const XPathArray
The canonical empty array.