XPathAtomic class abstract

Base class for all atomic values in the XDM 3.1 data model.

Implemented types
Implementers

Constructors

XPathAtomic()
Creates an atomic value.
const

Properties

effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isNumeric → bool
Whether this atomic value is numeric.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String
Canonical string representation of this item.
no setterinherited
type → XPathType
The XDM type of this item.
no setterinherited
value → Object
The underlying Dart value representation.
no setter

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
override
compareTo(XPathAtomic other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toValue() → Object
Converts this item to a native Dart value.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited