XPathBinary class final

Representation of binary atomic values (xs:base64Binary and xs:hexBinary).

Inheritance

Constructors

XPathBinary(Uint8List value, [XPathType type = xsBase64Binary])
Creates a new XPathBinary.
const
XPathBinary.fromBase64(String text)
Creates a new XPathBinary from base64 encoded text.
factory
XPathBinary.fromHex(String text)
Creates a new XPathBinary from hex encoded text.
factory

Properties

effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isNumeric → bool
Whether this atomic value is numeric.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String
Canonical string representation of this item.
no setteroverride
type → XPathType
The XDM type of this item.
final
value → Uint8List
The underlying Dart value representation.
final

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
inherited
compareTo(XPathAtomic other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toValue() → Object
Converts this item to a native Dart value.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override