XPathBoolean class final

Represents an xs:boolean atomic value.

Inheritance

Constructors

XPathBoolean(bool val)
Creates a boolean atomic value from val.
factory
XPathBoolean.from(bool val)
Creates a boolean atomic value from val.
factory
XPathBoolean.fromBool(bool val)
Creates a boolean atomic value from val.
factory

Properties

effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isNumeric → bool
Whether this atomic value is numeric.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String
Canonical string representation of this item.
no setteroverride
type → XPathType
The XDM type of this item.
no setteroverride
value → bool
The underlying Dart value representation.
final

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
inherited
compareTo(XPathAtomic other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toValue() → Object
Converts this item to a native Dart value.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

falseInstance → const XPathBoolean
The singleton false instance.
trueInstance → const XPathBoolean
The singleton true instance.