compareTo method
Compares this object to another object.
Returns a value like a Comparator when comparing this to other.
That is, it returns a negative integer if this is ordered before other,
a positive integer if this is ordered after other,
and zero if this and other are ordered together.
The other argument must be a value that is comparable to this object.
Implementation
@override
int compareTo(XPathAtomic other) {
if (other is XPathDateTime) {
if (type == other.type ||
(type.isSubtypeOf(xsDateTime) &&
other.type.isSubtypeOf(xsDateTime))) {
return utcInstant.compareTo(other.utcInstant);
}
}
return super.compareTo(other);
}