isAtSameMomentAs method
Checks if this instant is at the same moment as other.
Implementation
bool isAtSameMomentAs(XPathDateTime other) => compareTo(other) == 0;
Checks if this instant is at the same moment as other.
bool isAtSameMomentAs(XPathDateTime other) => compareTo(other) == 0;