tryParseDateTimeStamp static method
Attempts to parse a string representation of an xs:dateTimeStamp.
Implementation
static XPathDateTime? tryParseDateTimeStamp(String value) =>
tryParse(value, xsDateTimeStamp);
Attempts to parse a string representation of an xs:dateTimeStamp.
static XPathDateTime? tryParseDateTimeStamp(String value) =>
tryParse(value, xsDateTimeStamp);