XPathDecimal class final

Arbitrary-precision decimal (xs:decimal).

Inheritance

Constructors

XPathDecimal(BigInt unscaled, int scale)
factory
XPathDecimal.fromBigInt(BigInt val)
factory
XPathDecimal.fromInt(int val)
factory
XPathDecimal.fromNum(num val)
factory
XPathDecimal.parse(String text)
factory

Properties

effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isNumeric → bool
Whether this atomic value is numeric.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → int
final
stringValue → String
Canonical string representation of this item.
no setteroverride
type → XPathType
The XDM type of this item.
no setteroverride
unscaledValue → BigInt
final
value → Object
The underlying Dart value representation.
no setteroverride

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
inherited
compareTo(XPathAtomic other) → int
Compares this object to another object.
override
idiv(XPathNumeric other) → XPathInteger
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBigInt() → BigInt
override
toDecimal() → XPathDecimal
override
toDouble() → double
override
toString() → String
A string representation of this object.
inherited
toValue() → Object
Converts this item to a native Dart value.
override

Operators

operator %(XPathNumeric other) → XPathNumeric
override
operator *(XPathNumeric other) → XPathNumeric
override
operator +(XPathNumeric other) → XPathNumeric
override
operator -(XPathNumeric other) → XPathNumeric
override
operator /(XPathNumeric other) → XPathNumeric
override
operator ==(Object other) → bool
The equality operator.
override
operator unary-() → XPathDecimal
override

Static Properties

zero → XPathDecimal
final