operator >= method
Compares if this duration is greater than or equal to another.
Implementation
bool operator >=(XPathDuration other) => compareTo(other) >= 0;
Compares if this duration is greater than or equal to another.
bool operator >=(XPathDuration other) => compareTo(other) >= 0;