XPathErrorCode class

XPath 3.1 and XQuery standard error codes.

See www.w3.org/2005/xqt-errors/ for details.

Annotations
  • @immutable

Constructors

XPathErrorCode(String name, [String message = 'Unidentified error', String namespaceUri = standardNamespaceUri])
Creates a new XPathErrorCode with the given name, message, and optional namespaceUri.
const

Properties

code → String
The error code name (alias for name).
no setter
hashCode → int
The hash code for this object.
no setteroverride
message → String
The official standard error description.
final
name → String
The error code name (e.g. 'XPTY0004').
final
namespaceUri → String
The namespace URI of the error code.
final
qname → XPathQName
The qualified name of the error code in its error namespace.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

format([String? details]) → String
Formats the error message with the error code.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

tryFromCode(String code) → XPathErrorCode?
Looks up a known XPathErrorCode by its code name or qualified name, or returns null.

Constants

FOAP0001 → const XPathErrorCode
FOAR0001 → const XPathErrorCode
FOAR0002 → const XPathErrorCode
FOAY0001 → const XPathErrorCode
FOAY0002 → const XPathErrorCode
FOCA0001 → const XPathErrorCode
FOCA0002 → const XPathErrorCode
FOCA0003 → const XPathErrorCode
FOCA0005 → const XPathErrorCode
FOCA0006 → const XPathErrorCode
FOCH0001 → const XPathErrorCode
FOCH0002 → const XPathErrorCode
FOCH0003 → const XPathErrorCode
FOCH0004 → const XPathErrorCode
FODC0001 → const XPathErrorCode
FODC0002 → const XPathErrorCode
FODC0003 → const XPathErrorCode
FODC0004 → const XPathErrorCode
FODC0005 → const XPathErrorCode
FODC0006 → const XPathErrorCode
FODT0001 → const XPathErrorCode
FODT0002 → const XPathErrorCode
FODT0003 → const XPathErrorCode
FOER0000 → const XPathErrorCode
FOJS0001 → const XPathErrorCode
FOJS0003 → const XPathErrorCode
FOJS0005 → const XPathErrorCode
FOJS0006 → const XPathErrorCode
FOJS0007 → const XPathErrorCode
FONS0004 → const XPathErrorCode
FORG0001 → const XPathErrorCode
FORG0002 → const XPathErrorCode
FORG0003 → const XPathErrorCode
FORG0004 → const XPathErrorCode
FORG0005 → const XPathErrorCode
FORG0006 → const XPathErrorCode
FORG0008 → const XPathErrorCode
FORG0010 → const XPathErrorCode
FORX0001 → const XPathErrorCode
FORX0002 → const XPathErrorCode
FORX0003 → const XPathErrorCode
FORX0004 → const XPathErrorCode
FOTY0012 → const XPathErrorCode
FOTY0013 → const XPathErrorCode
FOTY0015 → const XPathErrorCode
FOUT1170 → const XPathErrorCode
FOUT1190 → const XPathErrorCode
FOUT1200 → const XPathErrorCode
SENR0001 → const XPathErrorCode
SEPM0004 → const XPathErrorCode
SEPM0016 → const XPathErrorCode
SEPM0017 → const XPathErrorCode
SEPM0018 → const XPathErrorCode
SEPM0019 → const XPathErrorCode
SERE0020 → const XPathErrorCode
SERE0022 → const XPathErrorCode
SERE0023 → const XPathErrorCode
standardNamespaceUri → const String
The standard XPath/XQuery error namespace URI.
values → const List<XPathErrorCode>
Standard list of predefined XPath error codes.
XPDY0002 → const XPathErrorCode
XPDY0050 → const XPathErrorCode
XPDY0130 → const XPathErrorCode
XPST0001 → const XPathErrorCode
XPST0003 → const XPathErrorCode
XPST0005 → const XPathErrorCode
XPST0008 → const XPathErrorCode
XPST0010 → const XPathErrorCode
XPST0017 → const XPathErrorCode
XPST0051 → const XPathErrorCode
XPST0080 → const XPathErrorCode
XPST0081 → const XPathErrorCode
XPTY0004 → const XPathErrorCode
XPTY0018 → const XPathErrorCode
XPTY0019 → const XPathErrorCode
XPTY0020 → const XPathErrorCode
XQDY0137 → const XPathErrorCode
XQST0039 → const XPathErrorCode
XQST0070 → const XPathErrorCode