FOCA0006 constant
XPathErrorCode
const FOCA0006
Implementation
static const FOCA0006 = XPathErrorCode(
'FOCA0006',
'String to be cast to decimal has too many digits of precision',
);
static const FOCA0006 = XPathErrorCode(
'FOCA0006',
'String to be cast to decimal has too many digits of precision',
);