XPST0003 constant
XPathErrorCode
const XPST0003
Implementation
static const XPST0003 = XPathErrorCode(
'XPST0003',
'Expression is not a valid instance of the grammar',
);
static const XPST0003 = XPathErrorCode(
'XPST0003',
'Expression is not a valid instance of the grammar',
);