XPTY0018 constant
XPathErrorCode
const XPTY0018
Implementation
static const XPTY0018 = XPathErrorCode(
'XPTY0018',
'Result of path operator contains both nodes and non-nodes',
);
static const XPTY0018 = XPathErrorCode(
'XPTY0018',
'Result of path operator contains both nodes and non-nodes',
);