XPTY0019 constant
XPathErrorCode
const XPTY0019
Implementation
static const XPTY0019 = XPathErrorCode(
'XPTY0019',
'Path expression does not evaluate to a sequence of nodes',
);
static const XPTY0019 = XPathErrorCode(
'XPTY0019',
'Path expression does not evaluate to a sequence of nodes',
);