XPTY0020 constant
XPathErrorCode
const XPTY0020
Implementation
static const XPTY0020 = XPathErrorCode(
'XPTY0020',
'Context item in axis step is not a node',
);
static const XPTY0020 = XPathErrorCode(
'XPTY0020',
'Context item in axis step is not a node',
);