XQDY0137 constant
XPathErrorCode
const XQDY0137
Implementation
static const XQDY0137 = XPathErrorCode(
'XQDY0137',
'No two keys in a map may have the same key value',
);
static const XQDY0137 = XPathErrorCode(
'XQDY0137',
'No two keys in a map may have the same key value',
);