XPathFunction class final

A callable XPath function item (builtin, anonymous, or partial).

Inheritance

Constructors

XPathFunction({required XmlName name, required int arity, required XPathFunctionCallback function})
Creates a callable XPath function item.
const

Properties

arity → int
The arity (number of required arguments) of the function item.
final
effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setterinherited
function → XPathFunctionCallback
final
hashCode → int
The hash code for this object.
no setterinherited
isVariadic → bool
Whether this function accepts variable arguments (at least arity).
no setterinherited
name → XmlName
The name of the function, if named.
final
parameterTypes → List<XPathType>?
The parameter types of the function, if statically known.
no setterinherited
returnType → XPathType?
The return type of the function, if statically known.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String
Canonical string representation of this item.
no setterinherited
type → XPathType
The XDM type of this item.
no setterinherited

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
inherited
call(XPathContext context, List<XPathSequence> arguments) → XPathSequence
Invokes the function item with the given arguments.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toValue() → Object
Converts this item to a native Dart value.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited