XPathFunctionType class

XDM 3.1 function type descriptor (e.g. function(*), function(xs:string) as xs:integer).

Inheritance

Constructors

XPathFunctionType({List<XPathType>? parameterTypes, XPathType? returnType})
Creates a function type with optional parameterTypes and returnType.
const

Properties

aliases → Iterable<String>
Aliases for parsing (e.g. URI-qualified names, short names).
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
isAny → bool
Whether this is the generic unconstrained function(*).
no setter
isAtomic → bool
Whether this type is an atomic type.
finalinherited
name → String
Canonical name of the type.
no setteroverride
parameterTypes → List<XPathType>?
Expected parameter types, or null for function(*).
final
parent → XPathType?
Parent type in the hierarchy, if any.
finalinherited
returnType → XPathType?
Expected return type, if specified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSubtypeOf(XPathType other) → bool
Whether this type is equal to or a subtype of other.
override
matchesItem(XPathItem item) → bool
Whether the item matches this type.
override
matchesSequence(XPathSequence sequence) → bool
Whether the sequence matches this type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override