XPathInteger class final

Arbitrary-precision integer (xs:integer and subtypes).

Inheritance

Constructors

XPathInteger(BigInt value, [XPathType type = xsInteger, int? intValue])
XPathInteger.fromInt(int val, [XPathType type = xsInteger])
factory
XPathInteger.parse(String text, [XPathType type = xsInteger])
factory

Properties

asInt → int
The value as a Dart int.
no setter
effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
intValue → int?
Cached 64-bit integer value, or null if the value overflows a 64-bit signed int.
final
isNumeric → bool
Whether this atomic value is numeric.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String
Canonical string representation of this item.
no setteroverride
type → XPathType
The XDM type of this item.
final
value → BigInt
The underlying Dart value representation.
final

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
inherited
compareTo(XPathAtomic other) → int
Compares this object to another object.
override
equalsInt(int other) → bool
Whether this integer equals the 64-bit integer other without BigInt allocation.
idiv(XPathNumeric other) → XPathInteger
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBigInt() → BigInt
override
toDecimal() → XPathDecimal
override
toDouble() → double
override
toString() → String
A string representation of this object.
inherited
toValue() → Object
Converts this item to a native Dart value.
override

Operators

operator %(XPathNumeric other) → XPathNumeric
override
operator *(XPathNumeric other) → XPathNumeric
override
operator +(XPathNumeric other) → XPathNumeric
override
operator -(XPathNumeric other) → XPathNumeric
override
operator /(XPathNumeric other) → XPathNumeric
override
operator ==(Object other) → bool
The equality operator.
override
operator unary-() → XPathInteger
override

Static Properties

zero → XPathInteger
final