XPathItem class abstract interface

Base interface for all items in the XDM 3.1 data model.

Implementers

Properties

effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String
Canonical string representation of this item.
no setter
type → XPathType
The XDM type of this item.
no setter

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toValue() → Object?
Converts this item to a native Dart value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited