get method
Returns the sequence associated with key, or null if not found.
Implementation
XPathSequence? get(XPathAtomic key) {
for (final entry in entries.entries) {
if (sameKey(entry.key, key)) return entry.value;
}
return null;
}
Returns the sequence associated with key, or null if not found.
XPathSequence? get(XPathAtomic key) {
for (final entry in entries.entries) {
if (sameKey(entry.key, key)) return entry.value;
}
return null;
}