XPathSequenceType class

Sequence type with item type and cardinality constraint.

Inheritance

Constructors

XPathSequenceType({required XPathType itemType, XPathCardinality cardinality = XPathCardinality.zeroOrMore})
Creates a sequence type with itemType and cardinality.
const

Properties

aliases → Iterable<String>
Aliases for parsing (e.g. URI-qualified names, short names).
finalinherited
cardinality → XPathCardinality
The cardinality of the sequence.
final
hashCode → int
The hash code for this object.
no setteroverride
isAtomic → bool
Whether this type is an atomic type.
finalinherited
itemType → XPathType
The item type of the sequence.
final
name → String
Canonical name of the type.
no setteroverride
parent → XPathType?
Parent type in the hierarchy, if any.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSubtypeOf(XPathType other) → bool
Whether this type is equal to or a subtype of other.
override
matchesItem(XPathItem item) → bool
Whether the item matches this type.
override
matchesSequence(XPathSequence sequence) → bool
Whether the sequence matches this sequence type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override