XPathString class final

Represents an xs:string (or derived subtype) atomic value.

Inheritance

Constructors

XPathString(String value, [XPathType type = xsString])
const

Properties

effectiveBooleanValue → bool
The effective boolean value (EBV) of this item.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isNumeric → bool
Whether this atomic value is numeric.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String
Canonical string representation of this item.
no setteroverride
type → XPathType
The XDM type of this item.
final
value → String
The underlying Dart value representation.
final

Methods

atomize() → XPathAtomic
Atomizes this item into an XPathAtomic value.
inherited
compareTo(XPathAtomic other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toValue() → Object
Converts this item to a native Dart value.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

empty → const XPathString
Canonical empty string.