XmlName class
XML entity name.
- Mixed-in types
- Annotations
-
- @immutable
Constructors
- XmlName(String localName, [String? namespacePrefix])
-
Creates a qualified XmlName from a
localNamename and an optionalnamespacePrefix.const - XmlName.fromString(String qualified)
-
Create a XmlName by parsing the provided
qualifiedname.const - XmlName.namespace({String? name})
-
Creates an XmlName for a namespace declaration with an optional
name.const -
XmlName.parse(String name, {String? namespaceUri, Map<
String, String> ? namespaceUris}) -
Creates an XmlName from a parsed string.
factory
- XmlName.parts(String local, {String? prefix, String? namespaceUri})
-
Creates an XmlName from a
localname and an optionalprefixand optionalnamespaceUri.const - XmlName.qualified(String qualified, {String? namespaceUri})
-
Creates a XmlName with the given
qualifiedname and an optionalnamespaceUri.const
Properties
- extendedQualified → String
-
The Extended QName (EQName) in the form
Q{uri}local, or the qualified name if the namespace URI is not defined or empty.no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- local → String
-
The local name, excluding the namespace prefix.
no setter
- namespaceUri → String?
-
The namespace URI, or
null.final - prefix → String?
-
The namespace prefix, or
null.no setter - qualified → String
-
The fully qualified name, including the namespace prefix.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept(
XmlVisitor visitor) → void -
Dispatch the invocation depending on this type to the
visitor.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
toXmlString(
{bool pretty = false, XmlEntityMapping? entityMapping, int? level, String? indent, String? newLine, Predicate< XmlNode> ? preserveWhitespace, Predicate<XmlAttribute> ? indentAttribute, Comparator<XmlAttribute> ? sortAttributes, Predicate<XmlNode> ? spaceBeforeSelfClose}) → String -
Return an XML string of this object.
inherited
-
withNamespaceUri(
String? namespaceUri) → XmlName -
Returns a new XmlName with the given
namespaceUri.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override