XPathArrayType class
XDM 3.1 array type descriptor (e.g. array(*), array(xs:string)).
Constructors
- XPathArrayType([XPathType memberType = xsSequence])
-
Creates an array type with
memberType.const
Properties
-
aliases
→ Iterable<
String> -
Aliases for parsing (e.g. URI-qualified names, short names).
finalinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAtomic → bool
-
Whether this type is an atomic type.
finalinherited
- memberType → XPathType
-
The member type of the array.
final
- name → String
-
Canonical name of the type.
no setteroverride
- parent → XPathType?
-
Parent type in the hierarchy, if any.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isSubtypeOf(
XPathType other) → bool -
Whether this type is equal to or a subtype of
other.override -
matchesItem(
XPathItem item) → bool -
Whether the
itemmatches this type.override -
matchesSequence(
XPathSequence sequence) → bool -
Whether the
sequencematches this type.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override