XPathDouble class final
64-bit IEEE 754 float (xs:double and xs:float).
- Inheritance
-
- Object
- XPathAtomic
- XPathNumeric
- XPathDouble
Constructors
- XPathDouble(double value, [XPathType type = xsDouble])
-
const
- XPathDouble.parse(String text, [XPathType type = xsDouble])
-
factory
Properties
- effectiveBooleanValue → bool
-
The effective boolean value (EBV) of this item.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setteroverride
- isNumeric → bool
-
Whether this atomic value is numeric.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String
-
Canonical string representation of this item.
no setteroverride
- type → XPathType
-
The XDM type of this item.
final
- value → double
-
The underlying Dart value representation.
final
Methods
-
atomize(
) → XPathAtomic -
Atomizes this item into an XPathAtomic value.
inherited
-
compareTo(
XPathAtomic other) → int -
Compares this object to another object.
override
-
idiv(
XPathNumeric other) → XPathInteger -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBigInt(
) → BigInt -
override
-
toDecimal(
) → XPathDecimal -
override
-
toDouble(
) → double -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
toValue(
) → Object -
Converts this item to a native Dart value.
inherited
Operators
-
operator %(
XPathNumeric other) → XPathNumeric -
override
-
operator *(
XPathNumeric other) → XPathNumeric -
override
-
operator +(
XPathNumeric other) → XPathNumeric -
override
-
operator -(
XPathNumeric other) → XPathNumeric -
override
-
operator /(
XPathNumeric other) → XPathNumeric -
override
-
operator ==(
Object other) → bool -
The equality operator.
override
-
operator unary-(
) → XPathDouble -
override
Static Methods
-
tryParse(
String text, [XPathType type = xsDouble]) → XPathDouble?
Constants
- infinity → const XPathDouble
- nan → const XPathDouble
- negativeInfinity → const XPathDouble
- zero → const XPathDouble