compareTo method
Compares this object to another object.
Returns a value like a Comparator when comparing this to other.
That is, it returns a negative integer if this is ordered before other,
a positive integer if this is ordered after other,
and zero if this and other are ordered together.
The other argument must be a value that is comparable to this object.
Implementation
@override
int compareTo(XPathAtomic other) {
if (other is XPathNumeric) {
final otherD = other.toDouble();
if (value.isNaN || otherD.isNaN) return -1;
if (value == otherD) return 0;
return value.compareTo(otherD);
}
return super.compareTo(other);
}