XPathFunctionItem class abstract
Base class for all function items (functions, maps, arrays) in XDM 3.1.
- Implemented types
- Implementers
Constructors
- XPathFunctionItem()
-
Creates a function item.
const
- XPathFunctionItem.fn0(XmlName name, XPathFunction0 function, {XPathType? returnType})
-
Creates a function item with 0 arguments.
constfactory
-
XPathFunctionItem.fn1(XmlName name, XPathFunction1 function, {List<
XPathType> ? parameterTypes, XPathType? returnType}) -
Creates a function item with 1 argument.
constfactory
-
XPathFunctionItem.fn2(XmlName name, XPathFunction2 function, {List<
XPathType> ? parameterTypes, XPathType? returnType}) -
Creates a function item with 2 arguments.
constfactory
-
XPathFunctionItem.fn3(XmlName name, XPathFunction3 function, {List<
XPathType> ? parameterTypes, XPathType? returnType}) -
Creates a function item with 3 arguments.
constfactory
-
XPathFunctionItem.fnN(XmlName name, int arity, XPathFunctionN function, {List<
XPathType> ? parameterTypes, XPathType? returnType}) -
Creates a function item with
arityarguments taking a list.constfactory -
XPathFunctionItem.function({required XmlName name, required int arity, required XPathFunctionN function, List<
XPathType> ? parameterTypes, XPathType? returnType}) -
Creates a general function item taking a list of arguments.
constfactory
-
XPathFunctionItem.overloaded(XmlName name, Map<
int, XPathFunctionItem> byArity) -
Creates an overloaded function item that dispatches across arities.
constfactory
-
XPathFunctionItem.variadic(XmlName name, int minArity, XPathFunctionN function, {List<
XPathType> ? parameterTypes, XPathType? returnType}) -
Creates a variadic function item with minimum arity
minArity.constfactory
Properties
- arity → int
-
The arity (number of required arguments) of the function item.
no setter
- effectiveBooleanValue → bool
-
The effective boolean value (EBV) of this item.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isVariadic → bool
-
Whether this function accepts variable arguments (at least arity).
no setter
- name → XmlName
-
The name of the function, if named.
no setter
-
parameterTypes
→ List<
XPathType> ? -
The parameter types of the function, if statically known.
no setter
- returnType → XPathType?
-
The return type of the function, if statically known.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String
-
Canonical string representation of this item.
no setteroverride
- type → XPathType
-
The XDM type of this item.
no setteroverride
Methods
-
atomize(
) → XPathAtomic -
Atomizes this item into an XPathAtomic value.
override
-
call(
XPathContext context, List< XPathSequence> arguments) → XPathSequence - Invokes the function item with the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
toValue(
) → Object -
Converts this item to a native Dart value.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited