XPathNode class final
Represents an XML node item in the XDM 3.1 data model.
- Implemented types
Properties
- effectiveBooleanValue → bool
-
The effective boolean value (EBV) of this item.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setteroverride
- node → XmlNode
-
The underlying XML DOM node.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String
-
Canonical string representation of this item.
no setteroverride
- type → XPathType
-
The XDM type of this item.
no setteroverride
Methods
-
atomize(
) → XPathAtomic -
Atomizes this item into an XPathAtomic value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
toValue(
) → XmlNode -
Converts this item to a native Dart value.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override