XPathNumeric class sealed
Sealed base class for all XDM numeric atomic values.
- Inheritance
-
- Object
- XPathAtomic
- XPathNumeric
- Implementers
Properties
- effectiveBooleanValue → bool
-
The effective boolean value (EBV) of this item.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNumeric → bool
-
Whether this atomic value is numeric.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String
-
Canonical string representation of this item.
no setterinherited
- type → XPathType
-
The XDM type of this item.
no setterinherited
- value → Object
-
The underlying Dart value representation.
no setterinherited
Methods
-
atomize(
) → XPathAtomic -
Atomizes this item into an XPathAtomic value.
inherited
-
compareTo(
XPathAtomic other) → int -
Compares this object to another object.
inherited
-
idiv(
XPathNumeric other) → XPathInteger -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBigInt(
) → BigInt -
toDecimal(
) → XPathDecimal -
toDouble(
) → double -
toString(
) → String -
A string representation of this object.
inherited
-
toValue(
) → Object -
Converts this item to a native Dart value.
inherited
Operators
-
operator %(
XPathNumeric other) → XPathNumeric -
operator *(
XPathNumeric other) → XPathNumeric -
operator +(
XPathNumeric other) → XPathNumeric -
operator -(
XPathNumeric other) → XPathNumeric -
operator /(
XPathNumeric other) → XPathNumeric -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator unary-(
) → XPathNumeric