XPathType class abstract
XDM 3.1 type descriptor hierarchy.
- Implementers
Constructors
Properties
-
aliases
→ Iterable<
String> -
Aliases for parsing (e.g. URI-qualified names, short names).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAtomic → bool
-
Whether this type is an atomic type.
final
- name → String
-
Canonical name of the type.
final
- parent → XPathType?
-
Parent type in the hierarchy, if any.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isSubtypeOf(
XPathType other) → bool -
Whether this type is equal to or a subtype of
other. -
matchesItem(
XPathItem item) → bool -
Whether the
itemmatches this type. -
matchesSequence(
XPathSequence sequence) → bool -
Whether the
sequencematches this type. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited